@@ -16,8 +16,8 @@ Axes: TypeAlias = list[list[Axis]]
 
 __all__ = [
     "axs_layout",
-    "plotting_context",
     "format_xticklabels",
+    "plotting_context",
     "set_style",
 ]
 
@@ -25,9 +25,7 @@ __all__ = [
 def format_xticklabels(
     ax: Axis, rotation: float | None = None, ha: str | None = None
 ) -> None:
-    ax.set_xticks(
-        ax.get_xticks(), ax.get_xticklabels(), rotation=rotation, ha=ha
-    )
+    ax.set_xticks(ax.get_xticks(), ax.get_xticklabels(), rotation=rotation, ha=ha)
 
 
 def axs_layout(
